:tocdepth: 2

.. meta::
    :description lang=en:
        Cloup is a library that extends the Click Python library with several features:
        option groups, constraints for group of parameters, the possibility
        to group the subcommands of a Group in multiple help sections and a
        custom help formatter with support for styling / theming.
    :keywords:
        python, cloup, click, option groups, help sections, constraints,
        mutually exclusive, help colors, help styling, help theming
    :google-site-verification: r5SEmg2wwCURBwKSrL_zQJEJbCVsScFhryur7zdFM3s

.. include:: ../README.rst
    :start-after: docs-index-start
    :end-before: docs-index-end


User guide
==========
Please, note that Cloup documentation doesn't replace
`Click documentation <https://click.palletsprojects.com/en/8.0.x/>`_.

.. toctree::
    :caption: User guide
    :maxdepth: 2

    pages/installation
    pages/arguments
    pages/option-groups
    pages/constraints
    pages/aliases
    pages/sections
    pages/formatting
    pages/misc


.. toctree::
    :caption: API reference
    :hidden:

    autoapi/cloup/index


.. toctree::
    :caption: Project
    :maxdepth: 2
    :hidden:

    GitHub Repository <https://github.com/janluke/cloup>
    Donate <https://www.paypal.com/donate?hosted_button_id=4GTN24HXPMNBJ>
    pages/contributing
    pages/credits
    pages/changelog
